@@ -4,12 +4,8 @@
  * - management of global state
  */
 /*
- *  This file is part of adns, which is
- *    Copyright (C) 1997-2000,2003,2006,2014-2016,2020  Ian Jackson
- *    Copyright (C) 2014  Mark Wooding
- *    Copyright (C) 1999-2000,2003,2006  Tony Finch
- *    Copyright (C) 1991 Massachusetts Institute of Technology
- *  (See the file INSTALL for full details.)
+ *  This file is part of adns, which is Copyright Ian Jackson
+ *  and contributors (see the file INSTALL for full details).
  *  
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -348,6 +344,8 @@ static void ccf_options(adns_state ads, const char *fn,
 	/* adns normally does IPv6 if the application wants it; control
 	 * this with the adns_af: option if you like */
 	WORD_IS("inet6") ||
+	/* adns trusts the resolver anyway */
+	WORD_IS("trust-ad") ||
 	/* adns does not do edns0 and this is not a problem */
 	WORD_IS("edns0"))
       continue;
